from FireNext.Table.__tag__ import *


class __read__table__:
    def __read__table__(self):

        try:
            table = open(self.__add__(".nt")).read()
            value = ""
            value2 = ""
            table_data = ""
            # table_data = "Table name : " + str(Table_Name) + "    Total Character : " + str(len(table))
            if table.__len__() > 0:
                Cell_Size = 0
                for x in range(table.__len__()):
                    if table[x] != cel__end__tag and table[x] != col__start__tag and table[x] != col__end__tag \
                            and table[x] != row__start__tag and table[x] != row__end__tag:
                        value = value + table[x]
                    elif table[x] == cel__end__tag:
                        if value.__len__() > Cell_Size:
                            Cell_Size = value.__len__()
                        value = ""
                    elif table[x] == col__end__tag or table[x] == row__end__tag:
                        if value.__len__() > Cell_Size:
                            Cell_Size = value.__len__()
                        value = ""

                for x1 in range(table.__len__()):
                    if table[x1] != cel__end__tag and table[x1] != col__start__tag and table[x1] != col__end__tag \
                            and table[x1] != row__start__tag and table[x1] != row__end__tag:
                        value = value + table[x1]
                    elif table[x1] == col__start__tag and value2 != "" or table[x1] == row__start__tag and value2 != "":
                        table_data = table_data + value2 + "\n"
                        table_data = table_data + value.ljust(value2.__len__(), "-") + "\n"
                        value2 = ""

                    elif table[x1] == cel__end__tag:
                        value = value.ljust(Cell_Size + 3, " ")
                        value2 = value2 + value
                        value = ""
                    elif table[x1] == col__end__tag or table[x1] == row__end__tag:
                        value = value.ljust(Cell_Size + 3, " ")
                        value2 = value2 + value
                        value = ""
                    if x1 == table.__len__() - 1:
                        # print(value2)
                        table_data = table_data + value2 + "\n"
                        return table_data
        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


from FireNext.Table.__tag__ import *


class __update__data__:
    def __update__data__(self, Search_Id, Column_Name, Update_Data):
        try:
            queryPosition = 0
            queryPermit = "false"
            updateData = "false"
            table = open(self.__add__(".nt")).read()
            value = ""
            updateDB = ""
            for x in range(table.__len__()):
                if queryPermit == "false" or queryPermit == "null":
                    updateDB = updateDB + table[x]
                if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                    x] != col__end__tag and queryPermit == "false":
                    value = value + table[x]
                elif table[x] == cel__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        queryPermit = "null"
                        value = ""

                    else:
                        queryPosition = queryPosition + 1
                        value = ""
                elif table[x] == col__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        queryPermit = "null"
                        value = ""

                    else:
                        return "'error' [" + Column_Name + "] column name not found"
                if table[x] == col__end__tag and queryPermit == "null":
                    queryPermit = "true"
                elif queryPermit == "true":
                    value = value + table[x]

                    if table[x] == row__end__tag:
                        data = ""
                        dataPosition = 0
                        for x1 in range(value.__len__()):
                            if value[x1] != row__start__tag and value[x1] != cel__end__tag and value[
                                x1] != row__end__tag:
                                data = data + value[x1]

                            elif value[x1] == cel__end__tag:
                                if data == Search_Id:
                                    updateData = "true"
                                    data = ""
                                    for x2 in range(value.__len__()):
                                        if value[x2] != row__start__tag and value[x2] != cel__end__tag and value[
                                            x2] != row__end__tag:
                                            data = data + value[x2]
                                        if value[x2] == row__start__tag:
                                            updateDB = updateDB + value[x2]
                                        elif value[x2] == cel__end__tag:
                                            dataPosition = dataPosition + 1
                                            if dataPosition == queryPosition:
                                                updateDB = updateDB + str(Update_Data) + cel__end__tag
                                                data = ""
                                            else:
                                                updateDB = updateDB + data + cel__end__tag
                                                data = ""
                                        if x2 == value.__len__() - 1:
                                            dataPosition = dataPosition + 1
                                            if dataPosition == queryPosition:
                                                updateDB = updateDB + str(Update_Data) + row__end__tag
                                                data = ""
                                            else:
                                                updateDB = updateDB + data + row__end__tag
                                                data = ""

                                    break

                                else:
                                    data = ""
                            elif value[x1] == row__end__tag:
                                if data == Search_Id:
                                    updateData = "true"

                                    data = ""
                                    for x2 in range(value.__len__()):
                                        if value[x2] != row__start__tag and value[x2] != cel__end__tag and value[
                                            x2] != row__end__tag:
                                            data = data + value[x2]
                                        if value[x2] == row__start__tag:
                                            updateDB = updateDB + value[x2]
                                        elif value[x2] == cel__end__tag:
                                            dataPosition = dataPosition + 1
                                            if dataPosition == queryPosition:
                                                updateDB = updateDB + str(Update_Data) + cel__end__tag
                                                data = ""
                                            else:
                                                updateDB = updateDB + data + cel__end__tag
                                                data = ""
                                        if x2 == value.__len__() - 1:
                                            dataPosition = dataPosition + 1
                                            if dataPosition == queryPosition:
                                                updateDB = updateDB + str(Update_Data) + row__end__tag
                                                data = ""
                                            else:
                                                updateDB = updateDB + data + row__end__tag
                                                data = ""

                                    break

                                else:
                                    data = ""
                            if x1 == value.__len__() - 1:
                                updateDB = updateDB + value

                        value = ""
                if x == table.__len__() - 1 and updateData == "false":
                    return "'error' [Search Id : " + Search_Id + "] not found"
                elif x == table.__len__() - 1:
                    table = open(self + ".nt", "w")
                    table.write(updateDB)
                    return "true"

        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


from FireNext.Table.__tag__ import *


class __add__col__name__:
    def __add__col__name__(self, Column_Name):
        try:
            table = open(self.__add__(".nt"), "r").read()

            if table.__len__() == 0:
                value = ""
                for x in range(Column_Name.__len__()):
                    if Column_Name[x] == devided__tag:
                        value = value + cel__end__tag
                    else:
                        value = value + Column_Name[x]
                table = open(self.__add__(".nt"), "w")
                table.write(col__start__tag + value + col__end__tag)
                return "true"
            elif table.__len__() > 0:
                queryPermit = "false"
                duplicateCondition = "false"
                duplicateColumnName = ""
                value = ""
                updateDB = ""
                for x in range(table.__len__()):

                    if table[x] != col__end__tag and queryPermit == "false":
                        updateDB = updateDB + table[x]
                    if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                        x] != col__end__tag and queryPermit == "false":
                        value = value + table[x]
                    elif table[x] == cel__end__tag and queryPermit == "false":
                        value1 = ""
                        for x1 in range(Column_Name.__len__()):
                            if Column_Name[x1] != devided__tag:
                                value1 = value1 + Column_Name[x1]
                            elif Column_Name[x1] == devided__tag:
                                if value == value1:
                                    duplicateCondition = "true"
                                    if duplicateColumnName == "":
                                        duplicateColumnName = value1
                                    else:
                                        duplicateColumnName = duplicateColumnName + cel__end__tag + value1
                                    break
                                else:
                                    value1 = ""
                            if x1 == len(Column_Name) - 1:
                                if value == value1:
                                    duplicateCondition = "true"
                                    if duplicateColumnName == "":
                                        duplicateColumnName = value1
                                    else:
                                        duplicateColumnName = duplicateColumnName + cel__end__tag + value1
                                    break
                                else:
                                    value1 = ""
                        value = ""

                    elif table[x] == col__end__tag and queryPermit == "false":
                        value1 = ""
                        for x1 in range(Column_Name.__len__()):
                            if Column_Name[x1] != devided__tag:
                                value1 = value1 + Column_Name[x1]
                            elif Column_Name[x1] == devided__tag:
                                if value == value1:
                                    duplicateCondition = "true"
                                    if duplicateColumnName == "":
                                        duplicateColumnName = value1
                                    else:
                                        duplicateColumnName = duplicateColumnName + cel__end__tag + value1
                                    break
                                else:
                                    value1 = ""
                            if x1 == len(Column_Name) - 1:
                                if value == value1:
                                    duplicateCondition = "true"
                                    if duplicateColumnName == "":
                                        duplicateColumnName = value1
                                    else:
                                        duplicateColumnName = duplicateColumnName + cel__end__tag + value1
                                    break
                                else:
                                    value1 = ""

                    if table[x] == col__end__tag and queryPermit == "false":
                        updateDB = updateDB + cel__end__tag + Column_Name + col__end__tag
                        queryPermit = "true"
                    elif queryPermit == "true":
                        updateDB = updateDB + table[x]
                    if x == len(table) - 1:
                        if duplicateCondition == "true":
                            return "'error' " + "[" + duplicateColumnName + "]" + " duplicate column name"
                        else:
                            table = open(self.__add__(".nt"), "w")
                            table.write(updateDB)
                            return "true"

        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass



from FireNext.Table.__tag__ import *
from FireNext.Table.__read__col__name__ import __read__col__name__
from FireNext.Table.__search__col__data__ import __search__col__data__
from FireNext.Table.__search__data__ import __search__data__
from FireNext.Table.__parent__update__ import __parent__update__
from FireNext.Doc.__self__add__ import __self__add__


class __convert__table__doc__:

    def __convert__table__doc__(self, child):
        value_child = __read__col__name__.__read__col__name__(self)
        child_id = __search__col__data__.__search__col__data__(self, child)
        child = ""
        for x in child_id:
            for x1 in value_child:
                value = __search__data__.__search__data__(self, x, x1)
                value = x1 + value__child__tag + value
                if child == "":
                    child = value
                else:
                    child = child + devided__tag + value

            if child != "":
                __self__add__.__self__add__(x + ">" + child)
                __parent__update__.__parent__update__(self, x)

            child = ""
        return "true"



from FireNext.Table.__tag__ import *


class __read__col__name__:
    def __read__col__name__(self):
        try:
            table = open(self.__add__(".nt"), "r").read()
            value = ""
            value2 = ""

            for x1 in range(table.__len__()):
                if table[x1] != cel__end__tag and table[x1] != col__start__tag and table[x1] != col__end__tag:
                    value = value + table[x1]

                elif table[x1] == cel__end__tag:
                    if value2 == "":
                        value2 = [value]
                    else:
                        value2.append(value)
                    value = ""
                elif table[x1] == col__end__tag:
                    if value2 == "":
                        value2 = [value]
                    else:
                        value2.append(value)
                    return value2
        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


from FireNext.Doc.__tag__ import *


class __self__child__:
    def __self__child__(self):
        value = ""
        databaseName = ""
        parentDatabaseName = ""
        for x in range(self.__len__()):
            if ">" != self[x]:
                value = value.__add__(self[x])
            if ">".__eq__(self[x]):
                if databaseName.__eq__(""):
                    try:
                        open(value.__add__(".ndb"), "r")
                        databaseName = value
                        value = ""
                    except:
                        return "'" + value + "' database not found"
                elif databaseName.__ne__(""):

                    childData = open(databaseName.__add__(".ndb"), "r").read()
                    if childData.__eq__(""):
                        return "'" + value + "' child not found"
                    elif childData.__ne__(""):
                        readChild = ""
                        updateNDB = ""
                        for x1 in range(childData.__len__()):
                            if childData[x1].__ne__(end__tag):
                                updateNDB = updateNDB + childData[x1]
                            if childData[x1].__ne__(start__tag) and childData[x1].__ne__(child__end__tag) and childData[
                                x1].__ne__(end__tag):
                                readChild = readChild + childData[x1]
                            if childData[x1].__eq__(child__end__tag):
                                if readChild.__eq__(value):
                                    try:
                                        open(value.__add__(".ndb"), "r")
                                        if parentDatabaseName == "":
                                            parentDatabaseName = databaseName
                                        else:
                                            parentDatabaseName = parentDatabaseName + ">" + databaseName
                                        databaseName = value
                                        value = ""
                                        break
                                    except:
                                        return "'" + value + "' database not found"
                                readChild = ""

                            if childData[x1].__eq__(end__tag) and x1.__eq__(len(childData) - 1):
                                if readChild.__eq__(value):
                                    try:
                                        open(value.__add__(".ndb"), "r")
                                        if parentDatabaseName == "":
                                            parentDatabaseName = databaseName
                                        else:
                                            parentDatabaseName = parentDatabaseName + ">" + databaseName
                                        databaseName = value
                                        value = ""
                                    except:
                                        return "'" + value + "' database not found"
                                else:
                                    return "'" + value + "' child not found"

                    value = ""

            if x.__eq__(len(self) - 1):
                try:
                    childData = open(databaseName.__add__(".ndb"), "r").read()
                except:
                    return print("'" + databaseName + "' child not found")

                if childData.__eq__(""):
                    return "false"
                elif childData.__ne__(""):
                    readChild = ""
                    updateNDB = ""
                    childMatch = "false"
                    childData = open(databaseName.__add__(".ndb"), "r").read()
                    for x2 in range(childData.__len__()):
                        if childData[x2].__ne__(start__tag) and childData[x2].__ne__(child__end__tag) and childData[
                            x2].__ne__(end__tag):
                            readChild = readChild + childData[x2]
                        if childData[x2].__eq__(child__end__tag):
                            if readChild == value:
                                return "true"
                            readChild = ""
                        if childData[x2].__eq__(value__child__tag):
                            if readChild == value:
                                return "true"
                        if x2.__eq__(len(childData) - 1):
                            if readChild == value:
                                return "true"
                            else:
                                return "false"

    def __len__(self):
        pass

    def __add__(self, other):
        pass



from FireNext.Table.__tag__ import *


class __parent__update__:
    def __parent__update__(self, child):
        try:
            database = open(self + ".ndb", "r").read()
            value = ""
            updateDB = ""
            child_update = "false"
            for x2 in range(database.__len__()):
                if database[x2] != start__tag and database[x2] != child__end__tag and database[
                    x2] != end__tag:
                    value = value + database[x2]
                if database[x2] == child__end__tag:
                    if child == value:
                        child_update = "true"
                        if updateDB == "":
                            updateDB = value + child__end__tag
                        else:
                            updateDB = updateDB + value + child__end__tag
                    else:
                        if updateDB == "":
                            updateDB = value + child__end__tag
                        else:
                            updateDB = updateDB + value + child__end__tag
                    value = ""
                if x2 == len(database) - 1:
                    if child != value:
                        if child_update == "false":
                            updateDB = updateDB + value + child__end__tag + child
                        else:
                            updateDB = updateDB + value
                    if child == value:
                        if updateDB == "":
                            updateDB = value
                        else:
                            updateDB = updateDB + value

            open(self + ".ndb", "w").write(start__tag + updateDB + end__tag)

        except:
            open(self + ".ndb", "w").write(start__tag + child + end__tag)


class __create__table__:
    def __create__table__(self):
        try:
            open(self.__add__(".nt"), "x")
            return "true"
        except:
            return "already" + ' "' + self + '" ' + "table created"

    def __add__(self, param):
        pass


from FireNext.Doc.__tag__ import *


class __self__check__:
    def __self__check__(self, condition):

        parent = ""
        valueChild = ""
        value = ""
        if condition == "add":
            for x in range(len(self)):

                if x >= 0:

                    if value == "" and self[x] == ' ':

                        value = ""

                    else:

                        value = value + self[x]

                if self[x] == '>':

                    if valueChild == "":

                        parent = parent + value
                        value = ""
                    else:
                        return "syntax"

                if self[x] == value__child__tag:

                    if len(value) != 1:
                        valueChild += value
                        value = ""
                    else:

                        return "child"

                if x == len(self) - 1:

                    if valueChild != "" and parent == "":
                        return "parent"
                    elif parent == "":

                        return "parent"

                    elif valueChild == "":

                        return "child"

                    else:

                        return parent + valueChild + value

        if condition == "child":

            for x in range(len(self)):

                if x >= 0:

                    if value == "" and self[x] == ' ':

                        value = ""

                    else:

                        value = value + self[x]

                if self[x] == '>':

                    if valueChild == "":

                        parent = parent + value
                        value = ""
                    else:
                        return "syntax"

                if self[x] == value__child__tag:

                    if len(value) != 1:
                        valueChild += value
                        value = ""
                    else:
                        return "child"
                if x == len(self) - 1:
                    return parent + valueChild + value

        if condition == "delete":

            for x in range(len(self)):

                if x >= 0:

                    if value == "" and self[x] == ' ':
                        value = ""
                    else:
                        value = value + self[x]

                if self[x] == '>':

                    if valueChild == "":

                        parent = parent + value
                        value = ""
                    else:
                        return "syntax"

                if self[x] == value__child__tag:

                    if len(value) != 1:
                        valueChild += value
                        value = ""
                    else:
                        return "child"
                if x == len(self) - 1:

                    if valueChild != "" and value != "":
                        return "syntax"
                    else:
                        return parent + valueChild + value

        if condition == "query":

            for x in range(len(self)):

                if x >= 0:

                    if value == "" and self[x] == ' ':
                        value = ""
                    else:
                        value = value + self[x]

                if self[x] == '>':

                    if valueChild == "":

                        parent = parent + value
                        value = ""
                    else:
                        return "syntax"

                if self[x] == value__child__tag:

                    if len(value) != 1:
                        valueChild += value
                        value = ""
                    else:
                        return "child"
                if x == len(self) - 1:

                    if parent == "":
                        return "parent"
                    else:
                        return parent + valueChild + value

        return parent + valueChild + value



from FireNext.Table.__tag__ import *


class __search__col__data__:
    def __search__col__data__(self, Column_Name):
        try:
            queryPosition = 0
            Cell_Size = 0
            queryPermit = "false"
            table = open(self.__add__(".nt")).read()
            value = ""
            returnValue = ""
            for x in range(table.__len__()):
                if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                    x] != col__end__tag and queryPermit == "false":
                    value = value + table[x]
                elif table[x] == cel__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        queryPermit = "null"
                        value = ""

                    else:
                        queryPosition = queryPosition + 1
                        value = ""
                elif table[x] == col__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        queryPermit = "null"
                        value = ""

                    else:
                        return "'error' [" + Column_Name + "] column name not found"
                if table[x] == col__end__tag and queryPermit == "null":
                    queryPermit = "true"
                elif queryPermit == "true":

                    value = value + table[x]

                    if table[x] == row__end__tag:
                        if Cell_Size == 0:
                            dataPosition = 0
                            value2 = ""
                            for x2 in range(table.__len__()):
                                if table[x2] != cel__end__tag and table[x2] != col__start__tag and table[
                                    x2] != col__end__tag \
                                        and table[x2] != row__start__tag and table[x2] != row__end__tag:
                                    value2 = value2 + table[x2]
                                elif table[x2] == cel__end__tag:

                                    dataPosition = dataPosition + 1
                                    if dataPosition == queryPosition:
                                        if value2.__len__() > Cell_Size:
                                            Cell_Size = value2.__len__()

                                    value2 = ""
                                elif table[x2] == col__end__tag or table[x2] == row__end__tag:
                                    dataPosition = dataPosition + 1
                                    if dataPosition == queryPosition:
                                        if value2.__len__() > Cell_Size:
                                            Cell_Size = value2.__len__()

                                    value2 = ""
                                    dataPosition = 0
                        dataPosition = 0
                        data = ""
                        for x1 in range(value.__len__()):
                            if value[x1] != row__start__tag and value[x1] != cel__end__tag and value[
                                x1] != row__end__tag:
                                data = data + value[x1]
                            elif value[x1] == cel__end__tag:
                                dataPosition = dataPosition + 1
                                if dataPosition == queryPosition:
                                    if returnValue == "":
                                        returnValue = [data]
                                    else:
                                        returnValue.append(data)
                                    break
                                else:
                                    data = ""
                            elif value[x1] == row__end__tag:
                                dataPosition = dataPosition + 1
                                if dataPosition == queryPosition:
                                    if returnValue == "":
                                        returnValue = [data]
                                    else:
                                        returnValue.append(data)
                                    break
                                else:
                                    data = ""
                        value = ""
                if x == table.__len__() - 1:
                    return returnValue
        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


import os
from FireNext.Doc.__tag__ import *
from FireNext.Doc.__self__update__ import __self__update__


class __self__child__delete__:
    def __self__child__delete__(self):
        value = ""
        parent = ""
        databaseName = ""
        for x in range(self.__len__()):
            if self[x] != ">":
                value = value + self[x]
            if self[x] == ">":
                value = value + self[x]
                parent = parent + value
                value = ""

            if x == self.__len__() - 1:
                if parent != "":

                    try:
                        dataBase = open(value + ".ndb", "r").read()
                    except:
                        return "'" + value + "' child not found"
                    if dataBase == start__tag+""+end__tag or dataBase == "":
                        __self__update__.__self__update__(parent[:-1], value)
                        os.remove(value + ".ndb")
                        return "true"
                    else:
                        databaseName = value
                        value = ""
                        childFound = "true"
                        for x1 in range(dataBase.__len__()):
                            if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[
                                x1] != end__tag:
                                value = value + dataBase[x1]
                            if dataBase[x1] == value__child__tag:
                                childFound = "false"
                            elif dataBase[x1] == child__end__tag:
                                if childFound == "true":
                                    __self__child__delete__.__self__child__delete__1(value)
                                    value = ""
                                else:
                                    value = ""
                                    childFound = "true"
                            if x1 == len(dataBase) - 1:
                                if childFound == "true":
                                    __self__child__delete__.__self__child__delete__1(value)
                                os.remove(databaseName + ".ndb")
                else:
                    try:
                        dataBase = open(value + ".ndb", "r").read()
                    except:
                        return "'" + value + "' child not found"
                    if dataBase == start__tag+""+end__tag or dataBase == "":

                        os.remove(value + ".ndb")
                        return "true"
                    else:
                        databaseName = value
                        value = ""
                        childFound = "true"
                        for x1 in range(dataBase.__len__()):
                            if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[
                                x1] != end__tag:
                                value = value + dataBase[x1]
                            if dataBase[x1] == value__child__tag:
                                childFound = "false"
                            elif dataBase[x1] == child__end__tag:
                                if childFound == "true":
                                    __self__child__delete__.__self__child__delete__1(value)
                                    value = ""
                                else:
                                    value = ""
                                    childFound = "true"
                            if x1 == len(dataBase) - 1:
                                if childFound == "true":
                                    __self__child__delete__.__self__child__delete__1(value)
                                os.remove(databaseName + ".ndb")

        if parent != "":
            __self__update__.__self__update__(parent[:-1], databaseName)
        return "true"

    def __self__child__delete__1(self):
        value = ""
        parent = ""
        for x in range(self.__len__()):
            if self[x] != ">":
                value = value + self[x]
            if self[x] == ">":
                parent = value
                value = ""

            if x == self.__len__() - 1:
                try:
                    dataBase = open(value + ".ndb", "r").read()
                except:
                    return "'" + value + "' child not found"
                if dataBase == start__tag+""+end__tag or dataBase == "":
                    os.remove(value + ".ndb")
                    return "true"
                else:
                    databaseName = value
                    value = ""
                    childFound = "true"
                    for x1 in range(dataBase.__len__()):
                        if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[x1] != end__tag:
                            value = value + dataBase[x1]
                        if dataBase[x1] == value__child__tag:
                            childFound = "false"
                        elif dataBase[x1] == child__end__tag:
                            if childFound == "true":
                                __self__child__delete__.__self__child__delete__2(value)
                                value = ""
                            else:
                                value = ""
                                childFound = "true"
                        if x1 == len(dataBase) - 1:
                            if childFound == "true":
                                __self__child__delete__.__self__child__delete__2(value)
                            os.remove(databaseName + ".ndb")
                            return "true"

    def __self__child__delete__2(self):
        value = ""
        parent = ""
        for x in range(self.__len__()):
            if self[x] != ">":
                value = value + self[x]
            if self[x] == ">":
                parent = value
                value = ""

            if x == self.__len__() - 1:
                try:
                    dataBase = open(value + ".ndb", "r").read()
                except:
                    return "'" + value + "' child not found"
                if dataBase == start__tag+""+end__tag or dataBase == "":
                    os.remove(value + ".ndb")
                    return "true"
                else:
                    databaseName = value
                    value = ""
                    childFound = "true"
                    for x1 in range(dataBase.__len__()):
                        if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[x1] != end__tag:
                            value = value + dataBase[x1]
                        if dataBase[x1] == value__child__tag:
                            childFound = "false"
                        elif dataBase[x1] == child__end__tag:
                            if childFound == "true":
                                __self__child__delete__.__self__child__delete__1(value)
                                value = ""
                            else:
                                value = ""
                                childFound = "true"
                        if x1 == len(dataBase) - 1:
                            if childFound == "true":
                                __self__child__delete__.__self__child__delete__1(value)
                            os.remove(databaseName + ".ndb")
                            return "true"

    def __len__(self):
        pass

    def __add__(self, other):
        pass



import os

from FireNext.Doc.__tag__ import *


class __self__update__:

    def __self__update__(self, child):
        parentValue = ""
        parent1 = ""
        for x in range(self.__len__()):
            if self[x] != ">":
                parentValue = parentValue + self[x]

            if self[x] == ">":
                parentValue = parentValue + self[x]
                parent1 = parent1 + parentValue
                parentValue = ""
            if x == len(self) - 1:
                dataBase = open(parentValue + ".ndb", "r").read()
                value = ""
                updateNDB = ""
                for x1 in range(dataBase.__len__()):
                    if dataBase[x1] == start__tag:
                        updateNDB = dataBase[x1]
                    if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[x1] != end__tag:
                        value = value + dataBase[x1]
                    if dataBase[x1] == child__end__tag:
                        if value == child:
                            updateNDB = updateNDB
                        else:
                            value = value + dataBase[x1]
                            updateNDB = updateNDB + value
                        value = ""
                    if x1 == len(dataBase) - 1:
                        if value == child:
                            if updateNDB == start__tag:
                                updateNDB = updateNDB + end__tag
                                open(parentValue.__add__(".ndb"), "w").write(updateNDB)
                            else:
                                updateNDB = updateNDB[:-1] + end__tag
                                open(parentValue.__add__(".ndb"), "w").write(updateNDB)

                            if updateNDB == start__tag+""+end__tag:
                                os.remove(parentValue + ".ndb")
                                if parent1 != "":
                                    __self__update__.__self__update__1(parent1[:-1], parentValue)
                        else:
                            updateNDB = updateNDB + value + end__tag
                            open(parentValue.__add__(".ndb"), "w").write(updateNDB)

    def __self__update__1(self, child):
        parentValue = ""
        parent1 = ""
        for x in range(self.__len__()):
            if self[x] != ">":
                parentValue = parentValue + self[x]

            if self[x] == ">":
                parentValue = parentValue + self[x]
                parent1 = parent1 + parentValue
                parentValue = ""
            if x == len(self) - 1:

                dataBase = open(parentValue + ".ndb", "r").read()
                value = ""
                updateNDB = ""
                for x1 in range(dataBase.__len__()):
                    if dataBase[x1] == start__tag:
                        updateNDB = dataBase[x1]
                    if dataBase[x1] != child__end__tag and dataBase[x1] != start__tag and dataBase[x1] != end__tag:
                        value = value + dataBase[x1]
                    if dataBase[x1] == child__end__tag:
                        if value != child:
                            value = value + dataBase[x1]
                            updateNDB = updateNDB + value

                        value = ""
                    if x1 == len(dataBase) - 1:
                        if value == child:
                            if updateNDB == start__tag:
                                updateNDB = updateNDB + end__tag
                                open(parentValue.__add__(".ndb"), "w").write(updateNDB)
                            else:
                                updateNDB = updateNDB[:-1] + end__tag
                                open(parentValue.__add__(".ndb"), "w").write(updateNDB)

                            if updateNDB == start__tag+""+end__tag:
                                os.remove(parentValue + ".ndb")
                                if parent1 != "":
                                    __self__update__.__self__update__(parent1[:-1], parentValue)
                        else:
                            updateNDB = updateNDB + value + end__tag
                            updateNDB = open(parentValue.__add__(".ndb"), "w").write(updateNDB)

    def __len__(self):
        pass

    def __add__(self, other):
        pass



from FireNext.Table.__tag__ import *


class __delete__col__:
    def __delete__col__(Table_Name, Column_Name):
        try:
            queryPosition = 0
            queryPermit = "false"
            table = open(Table_Name.__add__(".nt")).read()
            value = ""
            updateDB = ""
            for x in range(table.__len__()):
                if queryPermit == "false" and table[x] == col__start__tag or queryPermit == "null" and table[
                    x] == col__start__tag:
                    updateDB = updateDB + table[x]
                if queryPermit == "null" and table[x] != col__end__tag:
                    updateDB = updateDB + table[x]
                if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                    x] != col__end__tag and queryPermit == "false":
                    value = value + table[x]
                elif table[x] == cel__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        queryPermit = "null"
                        value = ""

                    else:
                        queryPosition = queryPosition + 1
                        updateDB = updateDB + value + cel__end__tag
                        value = ""
                elif table[x] == col__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        updateDB = updateDB[:-1]
                        queryPermit = "null"

                        value = ""

                    else:
                        return "'error' [" + Column_Name + "] column name not found"
                if table[x] == col__end__tag and queryPermit == "null":
                    updateDB = updateDB + value + col__end__tag
                    queryPermit = "true"
                elif queryPermit == "true":

                    value = value + table[x]

                    if table[x] == row__end__tag:
                        dataPosition = 0
                        data = ""
                        for x1 in range(value.__len__()):
                            if value[x1] != row__start__tag and value[x1] != cel__end__tag and value[
                                x1] != row__end__tag:
                                data = data + value[x1]
                            if value[x1] == row__start__tag:
                                updateDB = updateDB + value[x1]
                            elif value[x1] == cel__end__tag:
                                dataPosition = dataPosition + 1
                                if dataPosition == queryPosition:
                                    updateDB = updateDB
                                    data = ""
                                else:
                                    updateDB = updateDB + data + cel__end__tag
                                    data = ""
                            if x1 == value.__len__() - 1:
                                dataPosition = dataPosition + 1
                                if dataPosition == queryPosition:
                                    updateDB = updateDB[:-1] + row__end__tag
                                    data = ""
                                else:
                                    updateDB = updateDB + data + row__end__tag
                                    data = ""
                        value = ""

                if x == table.__len__() - 1:
                    table = open(Table_Name + ".nt", "w")
                    table.write(updateDB)
                    return "true"
        except:
            return "'error' " + '[' + Table_Name + ']' + " table not found"

    def __add__(self, param):
        pass


class __delete__table__:
    def __delete__table__(self):
        import os
        if os.path.exists(self.__add__(".nt")):
            os.remove(self.__add__(".nt"))
            return "true"
        else:
            return "'error' [" + self + "] table not found"

    def __add__(self, param):
        pass


from FireNext import __self__add__
from FireNext import __self__read__
from FireNext import __self__child__
from FireNext import __self__query__
from FireNext import __self__delete__
from FireNext import __self__check__


class NextDatabase:
    def add(path):
        """
           print(NextDatabase.add_data("USER>001>name:Mahfuz Salehin Moaz|age:26|nationality:Bangladesh"))
           output :
           USER
               |---001
               |     |---name:Mahfuz Salehin Moaz
               |     |---age:26
               |     |---nationality:Bangladesh

           ---------------------------------------------
           USER
               |---001
               |     |---name:Mahfuz Salehin Moaz
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------



           print(NextDatabase.add_data("USER>001>name:"))
           output :
           USER
               |---001
               |     |---name:

           ---------------------------------------------
           USER
               |---001
               |     |---name:
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------
        """
        check = __self__check__.__self__check__(path, "add")
        if check == "child":
            return "value child not found"
        if check == "parent":
            return "parent not found"
        if check == "syntax":
            return "'error' "+path

        return __self__add__.__self__add__(check)

    def read(path):
        """
           print(NextDatabase.read("USER>001>name:"))
           output : Mahfuz Salehin Moaz


           print(NextDatabase.read("USER"))
           output:
           --------------------------------------------
           USER
               |---001
               |     |---name:Mahfuz Salehin Moaz
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------

           print(NextDatabase.read("USER>001"))
           output:
           ---------------------------------
           001
             |---name:Mahfuz Salehin Moaz
             |---age:26
             |---nationality:Bangladesh
           ---------------------------------
        """
        check = __self__check__.__self__check__(path, "child")
        if check == "child":
            return "value child not found"
        if check == "syntax":
            return "'error' " + path
        return __self__read__.__self__read__(check)

    def hasChild(path):
        """
           print(NextDatabase.hasChild("USER>001>name:"))
           output : true

           ---------------------------------------------
           USER
               |---001
               |     |---name:Mahfuz Salehin Moaz
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------
        """
        check = __self__check__.__self__check__(path, "child")
        if check == "child":
            return "value child not found"
        if check == "syntax":
            return "'error' " + path
        return __self__child__.__self__child__(check)

    def query(path):
        """
           child = NextDatabase.query("USER>name:")
           output : [001,002,003]

           for x in child:

             if NextDatabase.hasChild("USER>"+x">name:") == "true":
                print(NextDatabase.read_data("USER>"+x">name:"))

           output : Mahfuz Salehin Moaz
                    Mithila Nisa
                    Sharmin
           ---------------------------------------------
           USER
               |---001
               |     |---name:Mahfuz Salehin Moaz
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------
        """
        check = __self__check__.__self__check__(path, "query")
        if check == "child":
            return "value child not found"
        if check == "parent":
            return "parent not found"
        if check == "syntax":
            return "'error' " + path
        return __self__query__.__self__query__(path)

    def delete(path):
        """
           print(NextDatabase.read_data("USER>001>name:"))
           output:
           ---------------------------------------------
           USER
               |---001
               |     |---age:26
               |     |---nationality:Bangladesh
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------


           print(NextDatabase.read_data("USER>001))
           output:
           ---------------------------------------------
           USER
               |---002
               |     |---name:Mithila Nisa
               |     |---age:23
               |     |---nationality:Bangladesh
               |---003
               |     |---name:Sharmin
               |     |---age:22
               |     |---nationality:Bangladesh
           ----------------------------------------------
        """
        check = __self__check__.__self__check__(path, "delete")
        if check == "child":
            return "value child not found"
        if check == "syntax":
            return "'error' " + path
        return __self__delete__.__self__delete__(check)




class __character__count__:
    def __character__count__(self):
        finalValue = ""

        for x in range(self.__len__()):

            value = self[x]
            if value != "0" and value != "1" and value != "2" and value != "3" and value != "4" and value != "5" and value \
                    != "6" and value != "7" and value != "8" and value != "9":
                count = finalValue.count(value, 0)
                if finalValue == "":
                    count = self.count(value, 0)
                    finalValue = value + " = " + str(count)
                elif count == 0:
                    count = self.count(value, 0)
                    finalValue = finalValue + "\n" + value + " = " + str(count)
            if x == len(self) - 1:
                for x1 in range(10):
                    count = self.count(str(x1), 0)
                    if count >= 1:
                        finalValue = finalValue + "\n" + str(x1) + " = " + str(count)

        return finalValue

    def __len__(self):
        pass


from FireNext.Doc.__tag__ import *
from FireNext.Doc.__self__child__delete__ import __self__child__delete__


class __self__delete__:
    def __self__delete__(self):
        value = ""
        databaseName = ""
        parentDatabaseName = ""
        for x in range(self.__len__()):
            if ">" != self[x]:
                value = value.__add__(self[x])
            if ">".__eq__(self[x]):
                if databaseName.__eq__(""):
                    try:
                        open(value.__add__(".ndb"), "r")
                        databaseName = value
                        value = ""
                    except:
                        return "'" + value + "' database not found"
                elif databaseName.__ne__(""):

                    childData = open(databaseName.__add__(".ndb"), "r").read()
                    if childData.__eq__(""):
                        return "'" + value + "' child not found"
                    elif childData.__ne__(""):
                        readChild = ""
                        updateNDB = ""
                        for x1 in range(childData.__len__()):
                            if childData[x1].__ne__(end__tag):
                                updateNDB = updateNDB + childData[x1]
                            if childData[x1].__ne__(start__tag) and childData[x1].__ne__(child__end__tag) and childData[
                                x1].__ne__(end__tag):
                                readChild = readChild + childData[x1]
                            if childData[x1].__eq__(child__end__tag):
                                if readChild.__eq__(value):
                                    try:
                                        open(value.__add__(".ndb"), "r")
                                        if parentDatabaseName == "":
                                            parentDatabaseName = databaseName
                                        else:
                                            parentDatabaseName = parentDatabaseName + ">" + databaseName
                                        databaseName = value
                                        value = ""
                                        break
                                    except:
                                        return "'" + value + "' database not found"
                                readChild = ""

                            if childData[x1].__eq__(end__tag) and x1.__eq__(len(childData) - 1):
                                if readChild.__eq__(value):
                                    try:
                                        open(value.__add__(".ndb"), "r")
                                        if parentDatabaseName == "":
                                            parentDatabaseName = databaseName
                                        else:
                                            parentDatabaseName = parentDatabaseName + ">" + databaseName
                                        databaseName = value
                                        value = ""
                                    except:
                                        return "'" + value + "' database not found"
                                else:
                                    return "'" + value + "' child not found"

                    value = ""

            if x.__eq__(len(self) - 1):

                if databaseName == "":
                    try:
                        open(value.__add__(".ndb"))
                        return __self__child__delete__.__self__child__delete__(value)
                    except:
                        return "'" + value + "' child not found"
                if value == "":
                    return "'" + databaseName + "' parent" + " child not found"

                childData = open(databaseName.__add__(".ndb"), "r").read()

                if childData.__eq__(""):
                    return "'" + value + "' child not found"
                elif childData.__ne__(""):
                    value1 = ""
                    name = ""
                    notFoundChild = ""
                    for x1 in range(value.__len__()):
                        if value[x1] != devided__tag:
                            value1 = value1 + value[x1]
                        if value[x1] == value__child__tag:
                            name = value1
                            value1 = ""
                        if value[x1] == devided__tag:
                            readChild = ""
                            updateNDB = ""
                            childMatch = "false"
                            childData = open(databaseName.__add__(".ndb"), "r").read()
                            for x2 in range(childData.__len__()):
                                if childData[x2].__eq__(start__tag):
                                    updateNDB = childData[x2]
                                if childData[x2].__ne__(start__tag) and childData[x2].__ne__(child__end__tag) and \
                                        childData[x2].__ne__(
                                                end__tag):
                                    readChild = readChild + childData[x2]
                                if childData[x2].__eq__(child__end__tag):
                                    if childMatch == "null" and updateNDB == start__tag:
                                        updateNDB = updateNDB
                                        childMatch = "true"
                                        continue
                                    if childMatch == "null" and updateNDB != start__tag:
                                        updateNDB = updateNDB
                                        childMatch = "true"
                                    elif childMatch == "false" and updateNDB == start__tag:
                                        updateNDB = updateNDB + readChild
                                    elif childMatch == "false" and updateNDB != "":
                                        updateNDB = updateNDB + child__end__tag + readChild
                                    readChild = ""
                                if childData[x2].__eq__(value__child__tag) and childMatch == "false":
                                    if readChild == name:
                                        childMatch = "null"
                                elif childMatch == "true":
                                    updateNDB = updateNDB + childData[x2]
                                if childData[x2].__eq__(end__tag) and x2.__eq__(len(childData) - 1):
                                    if childMatch == "true":
                                        open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                    if childMatch == "null":
                                        updateNDB = updateNDB + end__tag
                                        open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                    if childMatch == "false":
                                        notFoundChild = notFoundChild + "'" + name + "'"

                            name = ""
                            value1 = ""
                        if x1.__eq__(len(value) - 1):

                            if name == "":
                                try:
                                    open(value.__add__(".ndb"))
                                    parentDatabaseName = databaseName + ">" + value
                                    return __self__child__delete__.__self__child__delete__(parentDatabaseName)
                                except:
                                    return "'" + value + "' child not found"

                            readChild = ""
                            updateNDB = ""
                            childMatch = "false"
                            childData = open(databaseName.__add__(".ndb"), "r").read()
                            for x2 in range(childData.__len__()):
                                if childData[x2].__eq__(start__tag):
                                    updateNDB = childData[x2]
                                if childData[x2].__ne__(start__tag) and childData[x2].__ne__(child__end__tag) and \
                                        childData[x2].__ne__(
                                                end__tag):
                                    readChild = readChild + childData[x2]
                                if childData[x2].__eq__(child__end__tag):
                                    if childMatch == "null" and updateNDB == start__tag:
                                        updateNDB = updateNDB
                                        childMatch = "true"
                                        continue
                                    if childMatch == "null" and updateNDB != start__tag:
                                        updateNDB = updateNDB
                                        childMatch = "true"
                                    elif childMatch == "false" and updateNDB == start__tag:
                                        updateNDB = updateNDB + readChild
                                    elif childMatch == "false" and updateNDB != start__tag:
                                        updateNDB = updateNDB + child__end__tag + readChild
                                    readChild = ""
                                if childData[x2].__eq__(value__child__tag) and childMatch == "false":
                                    if readChild == name:
                                        childMatch = "null"
                                elif childMatch == "true":
                                    updateNDB = updateNDB + childData[x2]

                                if x2.__eq__(len(childData) - 1):

                                    if childMatch == "true":
                                        if updateNDB == start__tag+""+end__tag:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                            if parentDatabaseName == "":
                                                parentDatabaseName = databaseName
                                            else:
                                                parentDatabaseName = parentDatabaseName + ">" + databaseName
                                            __self__child__delete__.__self__child__delete__(parentDatabaseName)
                                            return "true"
                                        else:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                            return "true"

                                    if childMatch == "null":
                                        updateNDB = updateNDB + end__tag

                                        if updateNDB == start__tag+""+end__tag:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                            if parentDatabaseName == "":
                                                parentDatabaseName = databaseName
                                            else:
                                                parentDatabaseName = parentDatabaseName + ">" + databaseName
                                            __self__child__delete__.__self__child__delete__(parentDatabaseName)
                                            return "true"
                                        else:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                            return "true"

                                    if childMatch == "false":
                                        notFoundChild = notFoundChild + "'" + name + "'"

                                        updateNDB = childData[:-1] + value1 + end__tag
                                        if updateNDB == start__tag+""+end__tag:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)
                                            if parentDatabaseName == "":
                                                parentDatabaseName = databaseName
                                            else:
                                                parentDatabaseName = parentDatabaseName + ">" + databaseName
                                                __self__child__delete__.__self__child__delete__(parentDatabaseName)

                                        else:
                                            open(databaseName.__add__(".ndb"), "w").write(updateNDB)

                                        if notFoundChild != "":
                                            return notFoundChild + " child not found"
                    value = ""

    def __len__(self):
        pass

    def __add__(self, other):
        pass



from FireNext.Table.__tag__ import *


class __search__row__data__:
    def __search__row__data__(self, Search_Id):
        try:
            queryPermit = "false"
            table = open(self.__add__(".nt")).read()
            value = ""
            col_name = ""
            for x in range(table.__len__()):
                if queryPermit == "false":
                    col_name = col_name + table[x]

                if table[x] == col__end__tag and queryPermit == "false":
                    queryPermit = "true"
                elif queryPermit == "true":

                    value = value + table[x]

                    if table[x] == row__end__tag:
                        data = ""
                        for x1 in range(value.__len__()):
                            if value[x1] != row__start__tag and value[x1] != cel__end__tag and value[
                                x1] != row__end__tag:
                                data = data + value[x1]

                            elif value[x1] == cel__end__tag:
                                if data == Search_Id:

                                    col_name = value
                                    value = ""
                                    value2 = ""
                                    for x2 in range(col_name.__len__()):
                                        if col_name[x2] != cel__end__tag and col_name[x2] != col__start__tag and \
                                                col_name[
                                                    x2] != col__end__tag \
                                                and col_name[x2] != row__start__tag and col_name[x2] != row__end__tag:
                                            value = value + col_name[x2]
                                            
                                        elif col_name[x2] == cel__end__tag:
                                            if value2 == "":
                                                value2 = [value]
                                            else:
                                                value2.append(value)
                                            value = ""
                                        elif col_name[x2] == col__end__tag or col_name[x2] == row__end__tag:
                                            if value2 == "":
                                                value2 = [value]
                                            else:
                                                value2.append(value)
                                            value = ""
                                        if x2 == col_name.__len__() - 1:
                                            return value2
                                    break

                                else:
                                    data = ""
                            elif value[x1] == row__end__tag:
                                if data == Search_Id:

                                    col_name =  value
                                    value = ""
                                    value2 = ""
                                    for x2 in range(col_name.__len__()):
                                        if col_name[x2] != cel__end__tag and col_name[x2] != col__start__tag and \
                                                col_name[
                                                    x2] != col__end__tag \
                                                and col_name[x2] != row__start__tag and col_name[x2] != row__end__tag:
                                            value = value + col_name[x2]

                                        elif col_name[x2] == cel__end__tag:
                                            if value2 == "":
                                                value2 = [value]
                                            else:
                                                value2.append(value)
                                            value = ""
                                        elif col_name[x2] == col__end__tag or col_name[x2] == row__end__tag:
                                            if value2 == "":
                                                value2 = [value]
                                            else:
                                                value2.append(value)
                                            value = ""
                                        if x2 == col_name.__len__() - 1:
                                            return value2
                                    break
                        if x == table.__len__() - 1:
                            return "'error' [Search id : " + Search_Id + "] not found"
                        value = ""

        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass



from FireNext.Table.__tag__ import *


class __add__data__:
    def __add__data__(self, Data):
        try:
            table = open(self.__add__(".nt"))
            if len(table.read()) < 4:
                return "'error' column name not found\nbefore add data we need to add column name"
            else:
                value = ""
                for x in range(Data.__len__()):
                    if Data[x] == devided__tag:
                        value = value + cel__end__tag
                    else:
                        value = value + Data[x]
                open(self + ".nt", "a").write(row__start__tag + value + row__end__tag)
                return "true"
        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


from FireNext.Table.__tag__ import *


class __update__col__data__:
    def __update__col__data__(self, Column_Name, Update_Column_Name):
        try:
            queryPosition = 0
            queryPermit = "false"
            table = open(self.__add__(".nt")).read()
            value = ""
            updateDB = ""
            for x in range(table.__len__()):
                if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                    x] != col__end__tag and queryPermit == "false":
                    value = value + table[x]
                elif table[x] == cel__end__tag and queryPermit == "false":
                    if value == Update_Column_Name:
                        return "'error' " + "[" + value + "]" + " duplicate column name"

                    else:
                        value = ""
                elif table[x] == col__end__tag and queryPermit == "false":
                    if value == Update_Column_Name:
                        return "'error' " + "[" + value + "]" + " duplicate column name"
                    else:
                        value = ""
                        break
            for x in range(table.__len__()):
                if queryPermit == "false" and table[x] == col__start__tag or queryPermit == "null" and table[
                    x] == col__start__tag:
                    updateDB = updateDB + table[x]
                if queryPermit == "null" and table[x] != col__end__tag:
                    updateDB = updateDB + table[x]
                if table[x] != col__start__tag and table[x] != cel__end__tag and table[
                    x] != col__end__tag and queryPermit == "false":
                    value = value + table[x]
                elif table[x] == cel__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        updateDB = updateDB + str(Update_Column_Name) + cel__end__tag
                        queryPermit = "null"
                        value = ""

                    else:
                        queryPosition = queryPosition + 1
                        updateDB = updateDB + value + cel__end__tag
                        value = ""
                elif table[x] == col__end__tag and queryPermit == "false":
                    if value == Column_Name:
                        queryPosition = queryPosition + 1
                        updateDB = updateDB + str(Update_Column_Name)
                        queryPermit = "null"

                        value = ""

                    else:
                        return "'error' " + "[" + Column_Name + "]" + " Column name not found"
                if table[x] == col__end__tag and queryPermit == "null":
                    updateDB = updateDB + value + col__end__tag
                    queryPermit = "true"
                elif queryPermit == "true":
                    updateDB = updateDB + table[x]
                if x == len(table) - 1:
                    table = open(self + ".nt", "w")
                    table.write(updateDB)
                    return "true"
        except:
            return "'error' " + '[' + self + ']' + " table not found"

    def __add__(self, param):
        pass


from FireNext.Doc.__self__add__ import __self__add__
from FireNext.Doc.__self__read__ import __self__read__
from FireNext.Doc.__self__child__ import __self__child__
from FireNext.Doc.__self__delete__ import __self__delete__
from FireNext.Doc.__self__query__ import __self__query__
from FireNext.Doc.__self__check__ import __self__check__

from FireNext.Table.__delete__table__ import __delete__table__
from FireNext.Table.__create__table__ import __create__table__
from FireNext.Table.__read__table__ import __read__table__
from FireNext.Table.__convert__table__doc__ import __convert__table__doc__
from FireNext.Table.__read__col__name__ import __read__col__name__
from FireNext.Table.__search__data__ import __search__data__
from FireNext.Table.__add__col__name__ import __add__col__name__
from FireNext.Table.__update__col__data__ import __update__col__data__
from FireNext.Table.__delete__col__name__ import __delete__col__name__
from FireNext.Table.__search__row__data__ import __search__row__data__
from FireNext.Table.__delete__row__ import __delete__row__
from FireNext.Table.__search__col__data__ import __search__col__data__
from FireNext.Table.__delete__col__ import __delete__col__
from FireNext.Table.__update__row__ import __update__row__
from FireNext.Table.__delete__data__ import __delete__data__
from FireNext.Table.__update__data__ import __update__data__
from FireNext.Table.__add__data__ import __add__data__



col__start__tag = 'Á'
col__end__tag = 'À'
row__start__tag = 'É'
row__end__tag = 'È'
cel__end__tag = 'Ê'

start__tag = 'Á'
end__tag = 'À'
line__tag = "---"
child__end__tag = 'Ê'
devided__tag = '|'
value__child__tag = ':'




from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Programming Language :: Python :: 3.12'

]

setup(
    name='firenext',
    version='1.2.0',
    description='This is an offline database library.',
    long_description=open("README.md").read() + "\n\n" +
                     open("CHANGELOG.txt").read(),
    long_description_content_type='text/markdown',
    url='https://github.com/almoaz/PyFireNext',
    author='Mahfuz Salehin Moaz',
    author_email='almuaz1998@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='firenext',
    packages=find_packages()

)



from FireNext.Doc.__tag__ import *


class __self__:
    def __self__read__(self):
        return open(self.__add__(".ndb"), "r").read()

    def __self__(self):
        database = __self__.__self__read__(self)
        childValue = ""
        spaceLength = len(self)
        childName = ""
        returnValue = ""
        for x in range(database.__len__()):
            if database[x] != start__tag and database[x] != child__end__tag and database[x] != end__tag:
                childValue = childValue + database[x]
            if database[x] == value__child__tag:
                childName = childValue
                childValue = ""
            if database[x] == child__end__tag:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + childName + childValue
                    else:
                        returnValue = returnValue + "\n".ljust(spaceLength,
                                                               " ") + devided__tag + line__tag + childName + childValue
                    childName = ""
                    childValue = ""
                else:
                    space = "".ljust(spaceLength - 1, " ") + devided__tag + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__1(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + value
                    else:
                        returnValue = returnValue + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + value

                    childValue = ""
            if x == len(database) - 1:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + childName + childValue
                    else:
                        returnValue = returnValue + "\n".ljust(spaceLength,
                                                               " ") + devided__tag + line__tag + childName + childValue
                else:
                    space = "".ljust(spaceLength - 1, " ") + devided__tag + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__1(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + value
                    else:
                        returnValue = returnValue + "\n".ljust(spaceLength, " ") + devided__tag + line__tag + value
        return returnValue

    def __self__1(self, parentSpace):
        database = __self__.__self__read__(self)
        childValue = ""
        spaceLength = parentSpace
        childName = ""
        returnValue = ""
        for x in range(database.__len__()):
            if database[x] != start__tag and database[x] != child__end__tag and database[x] != end__tag:
                childValue = childValue + database[x]
            if database[x] == value__child__tag:
                childName = childValue
                childValue = ""
            if database[x] == child__end__tag:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + childName + childValue
                    elif returnValue != "":
                        returnValue = returnValue + "\n" + spaceLength + line__tag + childName + childValue

                    childName = ""
                    childValue = ""
                else:
                    space = spaceLength + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__2(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + value
                    else:
                        returnValue = returnValue + "\n" + spaceLength + line__tag + value

                    childValue = ""

            if x == len(database) - 1:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + childName + childValue
                    elif returnValue != "":
                        returnValue = returnValue + "\n" + spaceLength + line__tag + childName + childValue

                else:
                    space = spaceLength + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__2(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + value
                    else:
                        returnValue = returnValue + "\n" + spaceLength + line__tag + value

        return returnValue

    def __self__2(self, parentSpace):
        database = __self__.__self__read__(self)
        childValue = ""
        spaceLength = parentSpace
        childName = ""
        returnValue = ""
        for x in range(database.__len__()):
            if database[x] != start__tag and database[x] != child__end__tag and database[x] != end__tag:
                childValue = childValue + database[x]
            if database[x] == value__child__tag:
                childName = childValue
                childValue = ""
            if database[x] == child__end__tag:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + childName + childValue
                    elif returnValue != "":
                        returnValue = returnValue + "\n" + spaceLength + line__tag + childName + childValue

                    childName = ""
                    childValue = ""
                else:
                    space = spaceLength + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__1(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + value
                    else:
                        returnValue = returnValue + "\n" + spaceLength + line__tag + value

                    childValue = ""

            if x == len(database) - 1:
                if childName != "":
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + childName + childValue
                    elif returnValue != "":
                        returnValue = returnValue + "\n" + spaceLength + line__tag + childName + childValue

                else:
                    space = spaceLength + "".ljust(len(childValue) + 2) + devided__tag
                    value = __self__.__self__1(childValue, space)
                    if returnValue == "":
                        returnValue = self + "\n" + spaceLength + line__tag + value
                    else:
                        returnValue = returnValue + "\n" + spaceLength + line__tag + value

        return returnValue

    def __add__(self, param):
        pass

    def __len__(self):
        pass